@@ -54,6 +54,8 @@
 
 #[cfg(not(any(feature = "std", test)))]
 extern crate core as std;
+#[cfg(feature = "use_generic_array")]
+extern crate generic_array;
 
 use std::mem;
 use std::mem::ManuallyDrop;
